Package: d3po
Type: Package
Title: Fast and Beautiful Interactive Visualization Based on the 'D3'
        Engine
Version: 1.1.0
Authors@R: c(
  person("Mauricio", "Vargas Sepulveda", , "m.vargas.sepulveda@gmail.com", role = c("aut", "cre", "cph"),
    comment = c(ORCID = "0000-0003-1017-7574")),
  person("John", "Coene", role = "aut"),
  person("Ariel", "Alvarado", role = "ctb"),
  person("Sylvain", "Lesage", role = "ctb"),
  person("Curran", "Kelleher", role = "ctb"),
  person("Fernando", "Becerra", role = "ctb"),
  person(family = "Natural Earth", role = "dtc"),
  person(family = "R Consortium", role = "fnd", comment = "Funded for the 2016-2017 ISC grants cycle"))
Description: A fully FOSS alternative to 'Highcharter' based on 'D3' which provides 
  functions for both fast and beautiful interactive visualization for 'Markdown'
  'Shiny', and 'Tabler'.
Depends: htmlwidgets, R (>= 4.1)
URL: https://pacha.dev/d3po/
BugReports: https://github.com/pachadotdev/d3po/issues
License: Apache License (>= 2.0)
Encoding: UTF-8
LazyData: true
NeedsCompilation: no
Suggests: knitr, igraph, shiny, golem, geojsonsf, sf, jsonlite,
        rmarkdown, tintin
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
Packaged: 2026-07-20 11:29:12 UTC; pacha
Author: Mauricio Vargas Sepulveda [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0003-1017-7574>),
  John Coene [aut],
  Ariel Alvarado [ctb],
  Sylvain Lesage [ctb],
  Curran Kelleher [ctb],
  Fernando Becerra [ctb],
  Natural Earth [dtc],
  R Consortium [fnd] (Funded for the 2016-2017 ISC grants cycle)
Maintainer: Mauricio Vargas Sepulveda <m.vargas.sepulveda@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-20 12:20:37 UTC
Built: R 4.5.2; ; 2026-07-20 12:51:20 UTC; unix
