Package: d3po
Type: Package
Title: Fast and Beautiful Interactive Visualization for 'Markdown' and
        'Shiny'
Version: 1.0.3
Authors@R: c(
  person("Mauricio", "Vargas Sepulveda", , "m.vargas.sepulveda@gmail.com", role = c("aut", "cre", "cph"),
    comment = c(ORCID = "0000-0003-1017-7574")),
  person("John", "Coene", role = "aut"),
  person("Ariel", "Alvarado", role = "ctb"),
  person("Sylvain", "Lesage", role = "ctb"),
  person("Curran", "Kelleher", role = "ctb"),
  person("Fernando", "Becerra", role = "ctb"),
  person(family = "Natural Earth", role = "dtc"),
  person(family = "R Consortium", role = "fnd", comment = "Funded for the 2016-2017 ISC grants cycle"))
Description: Apache licensed alternative to 'Highcharter' which provides 
  functions for both fast and beautiful interactive visualization for 'Markdown'
  and 'Shiny'.
Depends: htmlwidgets, magrittr, R (>= 3.5)
URL: https://pacha.dev/d3po/
BugReports: https://github.com/pachadotdev/d3po/issues
License: Apache License (>= 2.0)
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Imports: assertthat, dplyr, purrr, rlang
Suggests: knitr, igraph, shiny, golem, geojsonsf, sf, jsonlite,
        rmarkdown
VignetteBuilder: knitr
Packaged: 2025-12-08 16:06:29 UTC; pacha
Author: Mauricio Vargas Sepulveda [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0003-1017-7574>),
  John Coene [aut],
  Ariel Alvarado [ctb],
  Sylvain Lesage [ctb],
  Curran Kelleher [ctb],
  Fernando Becerra [ctb],
  Natural Earth [dtc],
  R Consortium [fnd] (Funded for the 2016-2017 ISC grants cycle)
Maintainer: Mauricio Vargas Sepulveda <m.vargas.sepulveda@gmail.com>
Repository: CRAN
Date/Publication: 2025-12-08 21:50:09 UTC
Built: R 4.6.0; ; 2026-04-29 01:31:30 UTC; unix
