Package: d3poadvanceddemo
Title: Open `dev/01_start.R` to edit the title
Version: 0.0.0.9000
Authors@R: 
    person("Mauricio", "Vargas Sepulveda",
    role = c("aut","cre","cph"), 
    email = "m.sepulveda@mail.utoronto.ca", 
    comment = c(ORCID = "0000-0003-1017-7574"))
Description: Open `dev/01_start.R` to edit the description. This is an
    advanced demonstration of d3po functions.
License: Apache License (>= 2)
URL: https://github.com/pachadotdev/d3po
BugReports: https://github.com/pachadotdev/d3po/issues
Depends: 
    R (>= 2.10)
Imports: 
    config (>= 0.3.1),
    d3po,
    golem (>= 0.4.0),
    magrittr,
    rlang,
    shiny (>= 1.7.3),
    shinydashboard,
    stringr
Encoding: UTF-8
RoxygenNote: 7.2.3
