# Generated by roxygen2: do not edit by hand

S3method("$<-",uneval)
S3method("[",uneval)
S3method("[<-",uneval)
S3method("[[<-",uneval)
S3method(d3po,default)
S3method(d3po,igraph)
S3method(d3po,sf)
S3method(po_area,d3po)
S3method(po_area,d3proxy)
S3method(po_bar,d3po)
S3method(po_bar,d3proxy)
S3method(po_box,d3po)
S3method(po_box,d3proxy)
S3method(po_donut,d3po)
S3method(po_donut,d3proxy)
S3method(po_download,d3po)
S3method(po_download,d3proxy)
S3method(po_font,d3po)
S3method(po_font,d3proxy)
S3method(po_format,d3po)
S3method(po_format,d3proxy)
S3method(po_geomap,d3po)
S3method(po_geomap,d3proxy)
S3method(po_labels,d3po)
S3method(po_labels,d3proxy)
S3method(po_line,d3po)
S3method(po_line,d3proxy)
S3method(po_network,d3po)
S3method(po_network,d3proxy)
S3method(po_pie,d3po)
S3method(po_pie,d3proxy)
S3method(po_scatter,d3po)
S3method(po_scatter,d3proxy)
S3method(po_theme,d3po)
S3method(po_theme,d3proxy)
S3method(po_tooltip,d3po)
S3method(po_tooltip,d3proxy)
S3method(po_treemap,d3po)
S3method(po_treemap,d3proxy)
S3method(print,uneval)
export(d3po)
export(d3po_output)
export(d3po_proxy)
export(daes)
export(po_area)
export(po_bar)
export(po_box)
export(po_donut)
export(po_download)
export(po_font)
export(po_format)
export(po_geomap)
export(po_labels)
export(po_line)
export(po_network)
export(po_pie)
export(po_scatter)
export(po_theme)
export(po_tooltip)
export(po_treemap)
export(render_d3po)
importFrom(htmlwidgets,JS)
