# Generated by roxygen2: do not edit by hand

export("%>%")
export(run_app)
import(d3po)
import(shiny)
import(shinydashboard)
importFrom(d3po,d3po_output)
importFrom(dplyr,case_when)
importFrom(dplyr,count)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_if)
importFrom(dplyr,pull)
importFrom(dplyr,ungroup)
importFrom(golem,activate_js)
importFrom(golem,add_resource_path)
importFrom(golem,bundle_resources)
importFrom(golem,favicon)
importFrom(golem,with_golem_options)
importFrom(magrittr,"%>%")
importFrom(rlang,sym)
importFrom(shiny,column)
importFrom(shiny,shinyApp)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_to_lower)
importFrom(stringr,str_to_title)
